@@ -1,22 +1,23 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
 /* gtksourcecompletionprovider.c
+ * This file is part of GtkSourceView
  *
  * Copyright (C) 2007 - 2009 Jesús Barbero Rodríguez <chuchiperriman@gmail.com>
  * Copyright (C) 2009 - Jesse van den Kieboom <jessevdk@gnome.org>
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Library General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * GtkSourceView is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * GtkSourceView is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 
@@ -31,6 +32,10 @@
 
 #include <gtksourceview/gtksourcecompletionprovider.h>
 
+typedef GtkSourceCompletionProviderIface GtkSourceCompletionProviderInterface;
+
+G_DEFINE_INTERFACE(GtkSourceCompletionProvider, gtk_source_completion_provider, G_TYPE_OBJECT)
+
 /* Default implementations */
 static gchar *
 gtk_source_completion_provider_get_name_default (GtkSourceCompletionProvider *provider)
@@ -110,7 +115,7 @@ gtk_source_completion_provider_get_priority_default (GtkSourceCompletionProvider
 }
 
 static void 
-gtk_source_completion_provider_base_init (GtkSourceCompletionProviderIface *iface)
+gtk_source_completion_provider_default_init (GtkSourceCompletionProviderIface *iface)
 {
 	static gboolean initialized = FALSE;
 	
@@ -137,39 +142,6 @@ gtk_source_completion_provider_base_init (GtkSourceCompletionProviderIface *ifac
 	}
 }
 
-GType 
-gtk_source_completion_provider_get_type ()
-{
-	static GType gtk_source_completion_provider_type_id = 0;
-
-	if (!gtk_source_completion_provider_type_id)
-	{
-		static const GTypeInfo g_define_type_info = 
-		{ 
-			sizeof (GtkSourceCompletionProviderIface), 
-			(GBaseInitFunc) gtk_source_completion_provider_base_init, 
-			(GBaseFinalizeFunc) NULL, 
-			(GClassInitFunc) NULL, 
-			(GClassFinalizeFunc) NULL, 
-			NULL, 
-			0, 
-			0, 
-			(GInstanceInitFunc) NULL 
-		};
-						
-		gtk_source_completion_provider_type_id = 
-				g_type_register_static (G_TYPE_INTERFACE, 
-							"GtkSourceCompletionProvider", 
-							&g_define_type_info, 
-							0);
-
-		g_type_interface_add_prerequisite (gtk_source_completion_provider_type_id,
-		                                   G_TYPE_OBJECT);
-	}
-
-	return gtk_source_completion_provider_type_id;
-}
-
 /**
  * gtk_source_completion_provider_get_name:
  * @provider: a #GtkSourceCompletionProvider.
