@@ -1,22 +1,23 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
- *  gtksourcecontextengine.h
+ * gtksourcecontextengine.h
+ * This file is part of GtkSourceView
  *
- *  Copyright (C) 2003 - Gustavo Giráldez
- *  Copyright (C) 2005 - Marco Barisione, Emanuele Aina
+ * Copyright (C) 2003 - Gustavo Giráldez
+ * Copyright (C) 2005 - Marco Barisione, Emanuele Aina
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * GtkSourceView is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ * GtkSourceView is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef __GTK_SOURCE_CONTEXT_ENGINE_H__
@@ -36,14 +37,14 @@ G_BEGIN_DECLS
 
 typedef struct _GtkSourceContextData          GtkSourceContextData;
 typedef struct _GtkSourceContextReplace       GtkSourceContextReplace;
-
+typedef struct _GtkSourceContextClass         GtkSourceContextClass;
 typedef struct _GtkSourceContextEngine        GtkSourceContextEngine;
 typedef struct _GtkSourceContextEngineClass   GtkSourceContextEngineClass;
 typedef struct _GtkSourceContextEnginePrivate GtkSourceContextEnginePrivate;
 
 struct _GtkSourceContextEngine
 {
-	GtkSourceEngine engine;
+	GtkSourceEngine parent_instance;
 
 	/*< private >*/
 	GtkSourceContextEnginePrivate *priv;
@@ -75,6 +76,12 @@ GtkSourceContextData *_gtk_source_context_data_new	(GtkSourceLanguage	*lang);
 GtkSourceContextData *_gtk_source_context_data_ref	(GtkSourceContextData	*data);
 void		 _gtk_source_context_data_unref		(GtkSourceContextData	*data);
 
+GtkSourceContextClass *
+		gtk_source_context_class_new		(gchar const *name,
+							 gboolean     enabled);
+
+void		gtk_source_context_class_free		(GtkSourceContextClass *cclass);
+
 GtkSourceContextEngine *_gtk_source_context_engine_new  (GtkSourceContextData	*data);
 
 gboolean	 _gtk_source_context_data_define_context
@@ -85,6 +92,7 @@ gboolean	 _gtk_source_context_data_define_context
 							 const gchar		 *start_regex,
 							 const gchar		 *end_regex,
 							 const gchar		 *style,
+							 GSList			 *context_classes,
 							 GtkSourceContextFlags    flags,
 							 GError			**error);
 
@@ -95,6 +103,7 @@ gboolean	 _gtk_source_context_data_add_sub_pattern
 							 const gchar		 *name,
 							 const gchar		 *where,
 							 const gchar		 *style,
+							 GSList			 *context_classes,
 							 GError			**error);
 
 gboolean	 _gtk_source_context_data_add_ref 	(GtkSourceContextData	 *data,
