@@ -1,21 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
- *  gtksourcelanguagemanager.c
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
+/* gtksourcelanguagemanager.c
+ * This file is part of GtkSourceView
  *
- *  Copyright (C) 2003-2007 - Paolo Maggi <paolo.maggi@polito.it>
+ * Copyright (C) 2003-2007 - Paolo Maggi <paolo.maggi@polito.it>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * GtkSourceView is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ * GtkSourceView is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,6 +30,21 @@
 #include "gtksourceview-utils.h"
 #include <gio/gio.h>
 
+/**
+ * SECTION:languagemanager
+ * @Short_description: Object which provides access to #GtkSourceLanguage<!-- -->s
+ * @Title: GtkSourceLanguageManager
+ * @See_also: #GtkSourceLanguage
+ *
+ * #GtkSourceLanguageManager is an object which processes language description
+ * files and creates and stores #GtkSourceLanguage objects, and provides API to
+ * access them.
+ * Use gtk_source_language_manager_get_default() to retrieve the default
+ * instance of #GtkSourceLanguageManager, and
+ * gtk_source_language_manager_guess_language() to get a #GtkSourceLanguage for
+ * given file name and content type.
+ */
+
 #define RNG_SCHEMA_FILE		"language2.rng"
 #define LANGUAGE_DIR		"language-specs"
 #define LANG_FILE_SUFFIX	".lang"
@@ -168,7 +184,7 @@ gtk_source_language_manager_init (GtkSourceLanguageManager *lm)
  * manager or a private language manager instance then use
  * gtk_source_language_manager_get_default() instead.
  *
- * Returns: a #GtkSourceLanguageManager.
+ * Returns: a new #GtkSourceLanguageManager.
  */
 GtkSourceLanguageManager *
 gtk_source_language_manager_new (void)
@@ -181,7 +197,7 @@ gtk_source_language_manager_new (void)
  *
  * Returns the default #GtkSourceLanguageManager instance.
  *
- * Returns: a #GtkSourceLanguageManager. Return value is owned
+ * Returns: (transfer-none): a #GtkSourceLanguageManager. Return value is owned
  * by GtkSourceView library and must not be unref'ed.
  */
 GtkSourceLanguageManager *
@@ -209,7 +225,8 @@ notify_search_path (GtkSourceLanguageManager *mgr)
 /**
  * gtk_source_language_manager_set_search_path:
  * @lm: a #GtkSourceLanguageManager.
- * @dirs: a %NULL-terminated array of strings or %NULL.
+ * @dirs: (allow-none) (array zero-terminated=1):
+ * a %NULL-terminated array of strings or %NULL.
  *
  * Sets the list of directories where the @lm looks for
  * language files.
@@ -254,7 +271,8 @@ gtk_source_language_manager_set_search_path (GtkSourceLanguageManager *lm,
  *
  * Gets the list directories where @lm looks for language files.
  *
- * Returns: %NULL-terminated array containg a list of language files directories.
+ * Returns: (array zero-terminated) (transfer none): %NULL-terminated array
+ * containg a list of language files directories.
  * The array is owned by @lm and must not be modified.
  */
 G_CONST_RETURN gchar* G_CONST_RETURN *
@@ -367,7 +385,7 @@ ensure_languages (GtkSourceLanguageManager *lm)
 
 /**
  * gtk_source_language_manager_get_language_ids:
- * @lm: a #GtkSourceLanguageManager
+ * @lm: a #GtkSourceLanguageManager.
  *
  * Returns the ids of the available languages.
  *
@@ -393,7 +411,7 @@ gtk_source_language_manager_get_language_ids (GtkSourceLanguageManager *lm)
  * Gets the #GtkSourceLanguage identified by the given @id in the language
  * manager.
  *
- * Returns: a #GtkSourceLanguage, or %NULL if there is no language
+ * Returns: (transfer none): a #GtkSourceLanguage, or %NULL if there is no language
  * identified by the given @id. Return value is owned by @lm and should not
  * be freed.
  */
@@ -522,7 +540,7 @@ static GtkSourceLanguage *
 pick_lang_for_mime_type (GtkSourceLanguageManager *lm,
 			 const gchar              *content_type)
 {
-	GtkSourceLanguage *lang;
+	GtkSourceLanguage *lang = NULL;
 
 #ifndef G_OS_WIN32
 	/* On Unix "content type" is mime type */
@@ -538,8 +556,10 @@ pick_lang_for_mime_type (GtkSourceLanguageManager *lm,
 	{
 		GSList *langs;
 		
-		langs = pick_lang_for_filename (lm, alt_filename);
-		lang = GTK_SOURCE_LANGUAGE (langs->data);
+		langs = pick_langs_for_filename (lm, alt_filename);
+		
+		if (langs != NULL)
+			lang = GTK_SOURCE_LANGUAGE (langs->data);
 	}
 	
 	if (lang == NULL && mime_type != NULL)
@@ -554,8 +574,8 @@ pick_lang_for_mime_type (GtkSourceLanguageManager *lm,
 /**
  * gtk_source_language_manager_guess_language:
  * @lm: a #GtkSourceLanguageManager.
- * @filename: a filename in Glib filename encoding, or %NULL.
- * @content_type: a content type (as in GIO API), or %NULL.
+ * @filename: (allow-none): a filename in Glib filename encoding, or %NULL.
+ * @content_type: (allow-none): a content type (as in GIO API), or %NULL.
  *
  * Picks a #GtkSourceLanguage for given file name and content type,
  * according to the information in lang files. Either @filename or
@@ -590,7 +610,7 @@ pick_lang_for_mime_type (GtkSourceLanguageManager *lm,
  * etc. Use gtk_source_language_get_mime_types() and gtk_source_language_get_globs()
  * if you need full control over file -> language mapping.
  *
- * Returns: a #GtkSourceLanguage, or %NULL if there is no suitable language
+ * Returns: (transfer none): a #GtkSourceLanguage, or %NULL if there is no suitable language
  * for given @filename and/or @content_type. Return value is owned by @lm
  * and should not be freed.
  *
