@@ -1,28 +1,47 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
- *  gtksourcebuffer.c
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
+/* gtksourcemark.c
+ * This file is part of GtkSourceView
  *
- *  Copyright (C) 2007 by:
- *		Johannes Schmid <jhs@gnome.org>
+ * Copyright (C) 2007 - Johannes Schmid <jhs@gnome.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * GtkSourceView is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ * GtkSourceView is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "gtksourcemark.h"
 #include "gtksourcebuffer.h"
+#include "gtksourceview-i18n.h"
 
-#include <glib/gi18n.h>
+/**
+ * SECTION:mark
+ * @Short_description: mark object for #GtkSourceBuffer
+ * @Title: GtkSourceMark
+ * @See_also: #GtkSourceBuffer
+ *
+ * A #GtkSourceMark marks a position in the text where you want to display
+ * additional info. It is based on #GtkTextMark and thus is still valid after
+ * the text has changed though its position may change.
+ *
+ * #GtkSourceMark<!-- -->s are organised in categories which you have to set
+ * when you create the mark. Each category can have a pixbuf and a priority
+ * associated using #gtk_source_view_set_mark_category_pixbuf and
+ * #gtk_source_view_set_mark_category_priority. The pixbuf will be displayed in
+ * the margin at the line where the mark residents if the
+ * #GtkSourceView::show-line-marks property is set to TRUE. If there are
+ * multiple marks in the same line, the pixbufs will be drawn on top of each
+ * other. The mark with the highest priority will be drawn on top.
+ */
 
 enum
 {
@@ -91,9 +110,11 @@ gtk_source_mark_get_property (GObject    *object,
 static void
 gtk_source_mark_finalize (GObject *object)
 {
-	GtkSourceMark *mark = GTK_SOURCE_MARK(object);
+	GtkSourceMark *mark = GTK_SOURCE_MARK (object);
 
 	g_free (mark->priv->category);
+
+	G_OBJECT_CLASS (gtk_source_mark_parent_class)->finalize (object);
 }
 
 static void
@@ -110,8 +131,8 @@ gtk_source_mark_class_init (GtkSourceMarkClass *klass)
 	/**
 	 * GtkSourceMark:category:
 	 *
-	 * The category of the #GtkSourceMark, classified the mark and control
-	 * what pixbuf is used and with which priority it is drawn.
+	 * The category of the #GtkSourceMark, classifies the mark and controls
+	 * which pixbuf is used and with which priority it is drawn.
 	 */
 	g_object_class_install_property (object_class,
 					 PROP_CATEGORY,
@@ -120,7 +141,7 @@ gtk_source_mark_class_init (GtkSourceMarkClass *klass)
 							      _("The mark category"),
 							      NULL,
 							      G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	
+
 	g_type_class_add_private (object_class, sizeof (GtkSourceMarkPrivate));
 }
 
@@ -134,7 +155,7 @@ gtk_source_mark_init (GtkSourceMark *mark)
 /**
  * gtk_source_mark_new:
  * @name: Name of the #GtkSourceMark, can be NULL when not using a name
- * @category is used to classify marks according to common characteristics
+ * @category: is used to classify marks according to common characteristics
  * (e.g. all the marks representing a bookmark could belong to the "bookmark" 
  * category, or all the marks representing a compilation error could belong to 
  * "error" category).
@@ -145,7 +166,7 @@ gtk_source_mark_init (GtkSourceMark *mark)
  * Normally marks are created using the utility function 
  * gtk_source_buffer_create_mark().
  *
- * Returns: a new #GtkSourceMark that can be added using gtk_text_buffer_add_mark()
+ * Returns: a new #GtkSourceMark that can be added using gtk_text_buffer_add_mark().
  *
  * Since: 2.2
  */
@@ -164,11 +185,11 @@ gtk_source_mark_new (const gchar *name,
 
 /**
  * gtk_source_mark_get_category:
- * @mark: a #GtkSourceMark
+ * @mark: a #GtkSourceMark.
  *
- * Returns the mark category
+ * Returns the mark category.
  *
- * Returns: the category of the #GtkSourceMark
+ * Returns: the category of the #GtkSourceMark.
  *
  * Since: 2.2
  */
@@ -182,15 +203,15 @@ gtk_source_mark_get_category (GtkSourceMark *mark)
 
 /**
  * gtk_source_mark_next:
- * @mark: a #GtkSourceMark
- * @category: a string specifying the mark category or %NULL
+ * @mark: a #GtkSourceMark.
+ * @category: (allow-none): a string specifying the mark category, or %NULL.
  *
  * Returns the next #GtkSourceMark in the buffer or %NULL if the mark
  * was not added to a buffer. If there is no next mark, %NULL will be returned.
  *
- * If @category is %NULL, looks for marks of any category
+ * If @category is %NULL, looks for marks of any category.
  *
- * Returns: the next #GtkSourceMark or %NULL
+ * Returns: the next #GtkSourceMark, or %NULL.
  *
  * Since: 2.2
  */
@@ -212,15 +233,15 @@ gtk_source_mark_next (GtkSourceMark *mark,
 
 /**
  * gtk_source_mark_prev:
- * @mark: a #GtkSourceMark
- * @category: a string specifying the mark category or %NULL
+ * @mark: a #GtkSourceMark.
+ * @category: a string specifying the mark category, or %NULL.
  *
  * Returns the previous #GtkSourceMark in the buffer or %NULL if the mark
  * was not added to a buffer. If there is no previous mark, %NULL is returned.
  * 
  * If @category is %NULL, looks for marks of any category
  *
- * Returns: the previous #GtkSourceMark or %NULL
+ * Returns: the previous #GtkSourceMark, or %NULL.
  *
  * Since: 2.2
  */
